@@ -1,11 +1,73 @@
 #pragma once
 
 #include <array>
+#include <cstring>
 #include <sstream>
-#include <string.h>
+#include <string>
 
 namespace vroom {
 
+inline bool
+is_comment(const char* begin, const char* end, const std::string& comment) {
+  if (comment.empty() || comment.size() >= static_cast<size_t>(end - begin)) {
+    return false;
+  }
+
+  return strncmp(comment.data(), begin, comment.size()) == 0;
+}
+
+template <typename T>
+inline size_t skip_rest_of_line(const T& source, size_t start) {
+  auto out = memchr(source.data() + start, '\n', source.size() - start);
+  if (!out) {
+    return (source.size());
+  }
+  return static_cast<const char*>(out) - source.data();
+}
+
+inline bool
+is_empty_line(const char* begin, const char* end, const bool skip_empty_rows) {
+  if (!skip_empty_rows) {
+    return false;
+  }
+
+  if (skip_empty_rows && *begin == '\n') {
+    return true;
+  }
+
+  while (begin < end && (*begin == ' ' || *begin == '\t' || *begin == '\r')) {
+    ++begin;
+  }
+
+  return *begin == '\n';
+}
+
+inline bool is_blank_or_comment_line(
+    const char* begin,
+    const char* end,
+    const std::string& comment,
+    const bool skip_empty_rows) {
+  if (!skip_empty_rows && comment.empty()) {
+    return false;
+  }
+
+  if (skip_empty_rows && *begin == '\n') {
+    return true;
+  }
+
+  while (begin < end && (*begin == ' ' || *begin == '\t' || *begin == '\r')) {
+    ++begin;
+  }
+
+  if ((skip_empty_rows && *begin == '\n') ||
+      (!comment.empty() &&
+       strncmp(begin, comment.data(), comment.size()) == 0)) {
+    return true;
+  }
+
+  return false;
+}
+
 template <typename T>
 static size_t find_next_non_quoted_newline(
     const T& source, size_t start, const char quote = '"') {
@@ -47,24 +109,39 @@ static size_t find_next_non_quoted_newline(
 }
 
 template <typename T>
-static size_t
-find_next_newline(const T& source, size_t start, bool embedded_nl = true) {
+static size_t find_next_newline(
+    const T& source,
+    size_t start,
+    const std::string& comment,
+    const bool skip_empty_rows,
+    bool embedded_nl) {
+
+  if (start >= source.size()) {
+    return source.size() - 1;
+  }
+
   if (embedded_nl) {
     return find_next_non_quoted_newline(source, start);
   }
 
   auto begin = source.data() + start;
 
-  if (start >= source.size()) {
+  auto end = source.data() + source.size();
+
+  while (begin && begin < end) {
+    begin = static_cast<const char*>(memchr(begin, '\n', end - begin));
+    break;
+    if (!(begin && begin + 1 < end &&
+          is_blank_or_comment_line(begin + 1, end, comment, skip_empty_rows))) {
+      break;
+    }
+  }
+
+  if (!begin) {
     return source.size() - 1;
   }
 
-  auto res =
-      static_cast<const char*>(memchr(begin, '\n', source.size() - start));
-  if (!res) {
-    return source.size() - 1;
-  }
-  return res - source.data();
+  return begin - source.data();
 }
 
 template <typename T> T get_env(const char* name, T default_value) {
@@ -91,29 +168,11 @@ inline void trim_whitespace(const char*& begin, const char*& end) {
     ++begin;
   }
 
-  while (end != begin && is_space((end - 1))) {
+  while (end != begin && is_space(end - 1)) {
     --end;
   }
 }
 
-inline bool is_blank_or_comment_line(const char* begin, const char* comment) {
-  if (*begin == '\n') {
-    return true;
-  }
-
-  while (*begin == ' ' || *begin == '\t') {
-    ++begin;
-  }
-
-  size_t comment_len = strlen(comment);
-  if (*begin == '\n' ||
-      (comment_len > 0 && strncmp(begin, comment, strlen(comment)) == 0)) {
-    return true;
-  }
-
-  return false;
-}
-
 template <typename T> size_t skip_bom(const T& source) {
   /* Skip Unicode Byte Order Marks
 https://en.wikipedia.org/wiki/Byte_order_mark#Representations_of_byte_order_marks_by_encoding
@@ -169,20 +228,43 @@ EF BB BF:    UTF-8
 
 // This skips leading blank lines and comments (if needed)
 template <typename T>
-size_t find_first_line(const T& source, size_t skip, const char* comment) {
+size_t find_first_line(
+    const T& source,
+    size_t skip,
+    const char* comment,
+    const bool skip_empty_rows,
+    const bool embedded_nl) {
 
   auto begin = skip_bom(source);
   /* Skip skip parameters, comments and blank lines */
 
   while (bool should_skip =
-             (begin < source.size() - 1 &&
-              is_blank_or_comment_line(source.data() + begin, comment)) ||
+             (begin < source.size() - 1 && is_blank_or_comment_line(
+                                               source.data() + begin,
+                                               source.data() + source.size(),
+                                               comment,
+                                               skip_empty_rows)) ||
              skip > 0) {
-    begin = find_next_newline(source, begin) + 1;
+    begin = find_next_newline(
+                source,
+                begin,
+                "",
+                /* skip_empty_rows */ false,
+                embedded_nl) +
+            1;
     skip = skip > 0 ? skip - 1 : skip;
   }
 
   return begin;
 }
 
+inline bool
+matches(const char* start, const char* end, const std::string& needle) {
+  if (end <= start || static_cast<unsigned long>(end - start) < needle.size()) {
+    return false;
+  }
+  bool res = strncmp(start, needle.data(), needle.size()) == 0;
+  return res;
+}
+
 } // namespace vroom
